@@ -5,7 +5,7 @@ BEGIN {
 # ABSTRACT: A bundle of MIDI and music modules
 use strict;
 use warnings;
-our $VERSION = '0.0501';
+our $VERSION = '0.0502';
 1;
 
 __END__
@@ -20,7 +20,7 @@ Task::MusicBundle - A bundle of MIDI and music modules
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -48,6 +48,14 @@ included for the same reason.
 
 Task::MusicBundle - A bundle of MIDI and music modules
 
+=head1 VERSION
+
+version 0.0501
+
+=head1 NAME
+
+Task::MusicBundle - A bundle of MIDI and music modules
+
 =head1 CONTENTS
 
 L<Acme::Vuvuzela>
@@ -110,6 +118,8 @@ L<Music::Tempo> - Aug 08, 2003
 
 L<Music::Tension>
 
+L<Music::Voss>
+
 L<Text::Chord::Piano>
 
 =head1 TO DO
@@ -162,4 +172,15 @@ This software is copyright (c) 2014 by Gene Boggs.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Gene Boggs <gene@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Gene Boggs.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
